@@ -39,11 +39,13 @@ impl Icons {
     const FILE_OUTLINE: char    = '\u{f016}';  // 
     const FOLDER: char          = '\u{e5ff}';  // 
     const FOLDER_CONFIG: char   = '\u{e5fc}';  // 
+    const FOLDER_EXERCISM: char = '\u{ebe5}';  // 
     const FOLDER_GIT: char      = '\u{e5fb}';  // 
     const FOLDER_GITHUB: char   = '\u{e5fd}';  // 
     const FOLDER_HIDDEN: char   = '\u{f179e}'; // 󱞞
     const FOLDER_KEY: char      = '\u{f08ac}'; // 󰢬
     const FOLDER_NPM: char      = '\u{e5fa}';  // 
+    const FOLDER_OCAML: char    = '\u{e67a}';  // 
     const FOLDER_OPEN: char     = '\u{f115}';  // 
     const FONT: char            = '\u{f031}';  // 
     const FREECAD: char         = '\u{f336}';  // 
@@ -93,7 +95,7 @@ impl Icons {
     const LANG_PHP: char        = '\u{e73d}';  // 
     const LANG_PYTHON: char     = '\u{e606}';  // 
     const LANG_R: char          = '\u{e68a}';  // 
-    const LANG_RUBY: char       = '\u{e21e}';  // 
+    const LANG_RUBY: char       = '\u{e739}';  // 
     const LANG_RUBYRAILS: char  = '\u{e73b}';  // 
     const LANG_RUST: char       = '\u{e68b}';  // 
     const LANG_SASS: char       = '\u{e603}';  // 
@@ -155,9 +157,11 @@ impl Icons {
 /// all the directories that have a custom icon.
 const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     ".config"             => Icons::FOLDER_CONFIG,  // 
+    ".exercism"           => Icons::FOLDER_EXERCISM,// 
     ".git"                => Icons::FOLDER_GIT,     // 
     ".github"             => Icons::FOLDER_GITHUB,  // 
     ".npm"                => Icons::FOLDER_NPM,     // 
+    ".opam"               => Icons::FOLDER_OCAML,   // 
     ".ssh"                => Icons::FOLDER_KEY,     // 󰢬
     ".Trash"              => '\u{f1f8}',            // 
     "config"              => Icons::FOLDER_CONFIG,  // 
@@ -187,7 +191,6 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     "Videos"              => '\u{f03d}',            // 
     "xbps.d"              => Icons::FOLDER_CONFIG,  // 
     "xorg.conf.d"         => Icons::FOLDER_CONFIG,  // 
-    "hi"                  => Icons::BINARY,         // 
     "cabal"               => Icons::LANG_HASKELL,   // 
 };
 
@@ -217,7 +220,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".eslintrc.json"      => Icons::ESLINT,         // 
     ".eslintrc.yaml"      => Icons::ESLINT,         // 
     ".eslintrc.yml"       => Icons::ESLINT,         // 
-    ".fennelrc"           => Icons::CONFIG,         // 
+    ".gcloudignore"       => '\u{f11f6}',           // 󱇶
+    ".fennelrc"           => Icons::LANG_FENNEL,    // 
     ".gitattributes"      => Icons::GIT,            // 
     ".git-blame-ignore-revs" => Icons::GIT,         // 
     ".gitconfig"          => Icons::GIT,            // 
@@ -226,6 +230,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".gitlab-ci.yml"      => '\u{f296}',            // 
     ".gitmodules"         => Icons::GIT,            // 
     ".gtkrc-2.0"          => Icons::GTK,            // 
+    ".gvimrc"             => Icons::VIM,            // 
     ".htaccess"           => Icons::CONFIG,         // 
     ".htpasswd"           => Icons::CONFIG,         // 
     ".idea"               => Icons::INTELLIJ,       // 
@@ -238,6 +243,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".luaurc"             => Icons::CONFIG,         // 
     ".nanorc"             => '\u{e838}',            // 
     ".nuxtrc"             => '\u{f1106}',           // 󱄆
+    ".ocamlinit"          => Icons::LANG_OCAML,     // 
     ".mailmap"            => Icons::GIT,            // 
     ".node_repl_history"  => Icons::NODEJS,         // 
     ".npmignore"          => Icons::NPM,            // 
@@ -250,8 +256,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".pylintrc"           => Icons::CONFIG,         // 
     ".python_history"     => Icons::LANG_PYTHON,    // 
     ".rustfmt.toml"       => Icons::LANG_RUST,      // 
-    ".rvm"                => Icons::LANG_RUBY,      // 
-    ".rvmrc"              => Icons::LANG_RUBY,      // 
+    ".rvm"                => Icons::LANG_RUBY,      // 
+    ".rvmrc"              => Icons::LANG_RUBY,      // 
     ".SRCINFO"            => '\u{f303}',            // 
     ".tcshrc"             => Icons::SHELL,          // 󱆃
     ".viminfo"            => Icons::VIM,            // 
@@ -268,6 +274,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".zsh_history"        => Icons::SHELL,          // 󱆃
     ".zsh_sessions"       => Icons::SHELL,          // 󱆃
     "._DS_Store"          => Icons::OS_APPLE,       // 
+    "_gvimrc"             => Icons::VIM,            // 
+    "_vimrc"              => Icons::VIM,            // 
     "a.out"               => Icons::SHELL_CMD,      // 
     "authorized_keys"     => '\u{f08c0}',           // 󰣀
     "AUTHORS"             => '\u{edca}',            // 
@@ -288,6 +296,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "composer.json"       => Icons::LANG_PHP,       // 
     "composer.lock"       => Icons::LANG_PHP,       // 
     "config"              => Icons::CONFIG,         // 
+    "config.ru"           => Icons::LANG_RUBY,      // 
     "config.status"       => Icons::CONFIG,         // 
     "configure"           => Icons::WRENCH,         // 
     "configure.ac"        => Icons::CONFIG,         // 
@@ -312,10 +321,13 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "environment"         => Icons::CONFIG,         // 
     "favicon.ico"         => '\u{e623}',            // 
     "flake.lock"          => '\u{f313}',            // 
+    "fennelrc"            => Icons::LANG_FENNEL,    // 
     "fonts.conf"          => Icons::FONT,           // 
     "fp-info-cache"       => Icons::KICAD,          // 
     "fp-lib-table"        => Icons::KICAD,          // 
     "FreeCAD.conf"        => Icons::FREECAD,        // 
+    "Gemfile"             => Icons::LANG_RUBY,      // 
+    "Gemfile.lock"        => Icons::LANG_RUBY,      // 
     "GNUmakefile"         => Icons::MAKE,           // 
     "go.mod"              => Icons::LANG_GO,        // 
     "go.sum"              => Icons::LANG_GO,        // 
@@ -403,7 +415,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "qt5ct.conf"          => Icons::QT,             // 
     "qt6ct.conf"          => Icons::QT,             // 
     "QtProject.conf"      => Icons::QT,             // 
-    "Rakefile"            => Icons::LANG_RUBY,      // 
+    "Rakefile"            => Icons::LANG_RUBY,      // 
     "README"              => Icons::README,         // 󰂺
     "README.md"           => Icons::README,         // 󰂺
     "release.toml"        => Icons::LANG_RUST,      // 
@@ -411,7 +423,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "requirements.txt"    => Icons::LANG_PYTHON,    // 
     "robots.txt"          => '\u{f06a9}',           // 󰚩
     "rubydoc"             => Icons::LANG_RUBYRAILS, // 
-    "rvmrc"               => Icons::LANG_RUBY,      // 
+    "rvmrc"               => Icons::LANG_RUBY,      // 
     "SECURITY"            => '\u{f0483}',           // 󰒃
     "SECURITY.md"         => '\u{f0483}',           // 󰒃
     "settings.gradle.kts" => Icons::GRADLE,         // 
@@ -508,12 +520,13 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "cjs"            => Icons::LANG_JAVASCRIPT,  // 
     "class"          => Icons::LANG_JAVA,        // 
     "clj"            => '\u{e768}',              // 
+    "cljc"           => '\u{e768}',              // 
     "cljs"           => '\u{e76a}',              // 
     "cls"            => Icons::LANG_TEX,         // 
     "cmake"          => '\u{e794}',              // 
     "cmd"            => Icons::OS_WINDOWS,       // 
     "coffee"         => '\u{f0f4}',              // 
-    "com"            => Icons::OS_WINDOWS_CMD,   // 
+    "com"            => '\u{e629}',              // 
     "conda"          => '\u{e715}',              // 
     "conf"           => Icons::CONFIG,           // 
     "config"         => Icons::CONFIG,           // 
@@ -564,6 +577,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "dylib"          => Icons::OS_APPLE,         // 
     "ebook"          => Icons::BOOK,             // 
     "ebuild"         => '\u{f30d}',              // 
+    "edn"            => '\u{e76a}',              // 
     "editorconfig"   => '\u{e652}',              // 
     "eex"            => Icons::LANG_ELIXIR,      // 
     "ejs"            => '\u{e618}',              // 
@@ -582,6 +596,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "exe"            => Icons::OS_WINDOWS_CMD,   // 
     "exs"            => Icons::LANG_ELIXIR,      // 
     "f"              => Icons::LANG_FORTRAN,     // 󱈚
+    "f#"             => Icons::LANG_FSHARP,      // 
     "f3d"            => Icons::CAD,              // 󰻫
     "f3z"            => Icons::CAD,              // 󰻫
     "f90"            => Icons::LANG_FORTRAN,     // 󱈚
@@ -613,6 +628,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "fs"             => Icons::LANG_FSHARP,      // 
     "fsi"            => Icons::LANG_FSHARP,      // 
     "fsproj"         => Icons::LANG_FSHARP,      // 
+    "fsscript"       => Icons::LANG_FSHARP,      // 
     "fsx"            => Icons::LANG_FSHARP,      // 
     "gba"            => '\u{f1393}',             // 󱎓
     "gbl"            => Icons::EDA_PCB,          // 
@@ -623,9 +639,9 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "gcode"          => '\u{f0af4}',             // 󰫴
     "gd"             => Icons::GODOT,            // 
     "gdoc"           => Icons::DOCUMENT,         // 
-    "gem"            => Icons::LANG_RUBY,        // 
-    "gemfile"        => Icons::LANG_RUBY,        // 
-    "gemspec"        => Icons::LANG_RUBY,        // 
+    "gem"            => Icons::LANG_RUBY,        // 
+    "gemfile"        => Icons::LANG_RUBY,        // 
+    "gemspec"        => Icons::LANG_RUBY,        // 
     "gform"          => '\u{f298}',              // 
     "gif"            => Icons::IMAGE,            // 
     "git"            => Icons::GIT,              // 
@@ -646,7 +662,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "gto"            => Icons::EDA_PCB,          // 
     "gtp"            => Icons::EDA_PCB,          // 
     "gts"            => Icons::EDA_PCB,          // 
-    "guardfile"      => Icons::LANG_RUBY,        // 
+    "guardfile"      => Icons::LANG_RUBY,        // 
     "gv"             => Icons::GRAPH,            // 󱁉
     "gvy"            => Icons::LANG_GROOVY,      // 
     "gz"             => Icons::COMPRESSED,       // 
@@ -661,6 +677,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "heif"           => Icons::IMAGE,            // 
     "hex"            => '\u{f12a7}',             // 󱊧
     "hh"             => Icons::LANG_CPP,         // 
+    "hi"             => Icons::BINARY,           // 
     "hpp"            => Icons::LANG_CPP,         // 
     "hrl"            => '\u{e7b1}',              // 
     "hs"             => Icons::LANG_HASKELL,     // 
@@ -768,6 +785,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "md"             => Icons::MARKDOWN,         // 
     "md5"            => Icons::SHIELD_CHECK,     // 󰕥
     "mdb"            => Icons::DATABASE,         // 
+    "mdx"            => Icons::MARKDOWN,         // 
     "mid"            => '\u{f08f2}',             // 󰣲
     "mjs"            => Icons::LANG_JAVASCRIPT,  // 
     "mk"             => Icons::MAKE,             // 
@@ -851,6 +869,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ppt"            => Icons::SLIDE,            // 
     "pptx"           => Icons::SLIDE,            // 
     "prjpcb"         => Icons::EDA_PCB,          // 
+    "procfile"       => Icons::LANG_RUBY,        // 
     "properties"     => Icons::JSON,             // 
     "prql"           => Icons::DATABASE,         // 
     "ps"             => Icons::VECTOR,           // 󰕙
@@ -863,6 +882,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "psm1"           => Icons::POWERSHELL,       // 
     "pub"            => Icons::PUBLIC_KEY,       // 󰷖
     "purs"           => '\u{e630}',              // 
+    "pxd"            => Icons::LANG_PYTHON,      // 
     "pxm"            => Icons::IMAGE,            // 
     "py"             => Icons::LANG_PYTHON,      // 
     "pyc"            => Icons::LANG_PYTHON,      // 
@@ -870,6 +890,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "pyi"            => Icons::LANG_PYTHON,      // 
     "pyo"            => Icons::LANG_PYTHON,      // 
     "pyw"            => Icons::LANG_PYTHON,      // 
+    "pyx"            => Icons::LANG_PYTHON,      // 
     "qcow"           => Icons::DISK_IMAGE,       // 
     "qcow2"          => Icons::DISK_IMAGE,       // 
     "qm"             => Icons::TRANSLATION,      // 󰗊
@@ -877,10 +898,12 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "qrc"            => Icons::QT,               // 
     "qss"            => Icons::QT,               // 
     "r"              => Icons::LANG_R,           // 
+    "rake"           => Icons::LANG_RUBY,        // 
+    "rakefile"       => Icons::LANG_RUBY,        // 
     "rar"            => Icons::COMPRESSED,       // 
     "raw"            => Icons::IMAGE,            // 
     "razor"          => Icons::RAZOR,            // 
-    "rb"             => Icons::LANG_RUBY,        // 
+    "rb"             => Icons::LANG_RUBY,        // 
     "rdata"          => Icons::LANG_R,           // 
     "rdb"            => '\u{e76d}',              // 
     "rdoc"           => Icons::MARKDOWN,         // 
@@ -892,13 +915,13 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "rmeta"          => Icons::LANG_RUST,        // 
     "rpm"            => '\u{e7bb}',              // 
     "rs"             => Icons::LANG_RUST,        // 
-    "rspec"          => Icons::LANG_RUBY,        // 
-    "rspec_parallel" => Icons::LANG_RUBY,        // 
-    "rspec_status"   => Icons::LANG_RUBY,        // 
+    "rspec"          => Icons::LANG_RUBY,        // 
+    "rspec_parallel" => Icons::LANG_RUBY,        // 
+    "rspec_status"   => Icons::LANG_RUBY,        // 
     "rss"            => '\u{f09e}',              // 
     "rst"            => Icons::TEXT,             // 
     "rtf"            => Icons::TEXT,             // 
-    "ru"             => Icons::LANG_RUBY,        // 
+    "ru"             => Icons::LANG_RUBY,        // 
     "rubydoc"        => Icons::LANG_RUBYRAILS,   // 
     "s"              => Icons::LANG_ASSEMBLY,    // 
     "s3db"           => Icons::SQLITE,           // 
