@@ -224,7 +224,7 @@ impl Column {
             #[cfg(unix)]
             Self::Inode => "inode",
             Self::GitStatus => "Git",
-            Self::SubdirGitRepo(_) => "Repo",
+            Self::SubdirGitRepo(_) => "Git Repo",
             #[cfg(unix)]
             Self::Octal => "Octal",
             #[cfg(unix)]
@@ -497,7 +497,7 @@ impl<'a> Table<'a> {
         Some(f::PermissionsPlus {
             file_type: file.type_char(),
             #[cfg(windows)]
-            attributes: file.attributes(),
+            attributes: file.attributes()?,
             xattrs,
         })
     }
